@@ -30,10 +30,11 @@
 		
 """
 
-import unittest, os
+import unittest, os, sys
 import StringIO
 import logging, logging.config
-import xml.sax, xml.sax.handler, md5
+import xml.sax, xml.sax.handler
+from hashlib import md5
 try:
     # check to see if pyxml is installed
     from xml.sax.saxlib import LexicalHandler
@@ -59,7 +60,7 @@ class XMLChecksumHandler (xml.sax.handler.ContentHandler, xml.sax.handler.DTDHan
 		return self.digest.hexdigest()
 
 	def startDocument (self):
-		self.digest = md5.new()
+		self.digest = md5()
 		
 	def startPrefixMapping (self, prefix, uri):
 		self.digest.update (prefix)
@@ -114,7 +115,7 @@ class XMLChecksumHandler (xml.sax.handler.ContentHandler, xml.sax.handler.DTDHan
 		self.digest.update (name)
 		self.digest.update (publicId)
 		self.digest.update (systemId)
-                
+
 CHECKSUMPARSER = xml.sax.make_parser()
 CHECKSUMHANDLER = XMLChecksumHandler(CHECKSUMPARSER)
 CHECKSUMPARSER.setContentHandler (CHECKSUMHANDLER)
@@ -142,7 +143,7 @@ class TALHandlerTestCases (unittest.TestCase):
 	def _runTest_ (self, txt, result, errMsg="Error"):
 		template = simpleTAL.compileXMLTemplate (txt)
 		fh = StringIO.StringIO ()
-		template.expand (self.context, fh)
+		template.expand (self.context, fh, outputEncoding="iso-8859-1")
 		realResult = fh.getvalue()
 		expectedChecksum = getXMLChecksum (result)
 		try:
@@ -201,7 +202,7 @@ class TALHandlerTestCases (unittest.TestCase):
 		txt = """<?xml version="1.0" encoding="iso-8859-1"?>\n<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">\n<html><p>Test</p></html>"""
 		template = simpleTAL.compileXMLTemplate (txt)
 		fh = StringIO.StringIO ()
-		template.expand (self.context, fh, docType="""<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3c.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">""")
+		template.expand (self.context, fh, docType="""<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3c.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">""", outputEncoding="iso-8859-1")
 		realResult = fh.getvalue()
 		expectedResult = """<?xml version="1.0" encoding="iso-8859-1"?>\n<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3c.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">\n<html><p>Test</p></html>"""
 		self.failUnless (realResult == expectedResult, "Doctype failed - \npassed in: %s \ngot back %s \nexpected %s\n\nTemplate: %s" % (txt, realResult, expectedResult, str(template)))
@@ -215,6 +216,15 @@ class TALHandlerTestCases (unittest.TestCase):
 		expectedResult = """<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3c.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">\n<html><p>Test</p></html>"""
 		self.failUnless (realResult == expectedResult, "Doctype failed - \npassed in: %s \ngot back %s \nexpected %s\n\nTemplate: %s" % (txt, realResult, expectedResult, str(template)))
 
+	def testNBSPparsing (self):
+		txt = """<?xml version="1.0" encoding="iso-8859-1"?>\n<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">\n<html><p>Test&nbsp;Space</p></html>"""
+		template = simpleTAL.compileXMLTemplate (txt)
+		fh = StringIO.StringIO ()
+		template.expand (self.context, fh)
+		realResult = fh.getvalue()
+		expectedResult = u"""<?xml version="1.0"?>\n<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">\n<html><p>Test\xa0Space</p></html>""".encode ("utf-8")
+		self.failUnless (realResult == expectedResult, "NBSP expansion failed - \npassed in: %s \ngot back %s \nexpected %s\n\nTemplate: %s" % (txt, realResult, expectedResult, template))
+
 	def testXMLDeclarationSuppressionWithNoDocType (self):
 		txt = """<?xml version="1.0" encoding="iso-8859-1"?>\n<html><p>Test</p></html>"""
 		template = simpleTAL.compileXMLTemplate (txt)
@@ -268,4 +278,3 @@ class TALHandlerTestCases (unittest.TestCase):
 
 if __name__ == '__main__':
 	unittest.main()
-	
